@@ -3,20 +3,19 @@ package Aspect::Advice;
 use strict;
 use warnings;
 use Carp;
-use Aspect::AdviceContext;
-use Aspect::Weaver;
+use Aspect::AdviceContext  ();
+use Aspect::Advice::After  ();
+use Aspect::Advice::Before ();
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 sub new {
-	my ($class, $type, $code, $pointcut) = @_;
-	my $self = bless {
-		weaver   => Aspect::Weaver->new, # a weaver that will install advice code
-		hooks    => undef,               # list of Hook::LexWrap hooks
-		type     => $type,               # before or after
-		code     => $code,               # the advice code
-		pointcut => $pointcut,           # the advice pointcut
-	}, $class;
+	my $class = "Aspect::Advice::" . ucfirst($_[1]); # Yes, a bit hacky
+	my $self  = $class->new(
+		hooks    => undef, # List of symbol table hooks
+		code     => $_[2], # the advice code
+		pointcut => $_[3], # the advice pointcut
+	);
 	$self->install;
 	return $self;
 }
@@ -24,72 +23,15 @@ sub new {
 # private ---------------------------------------------------------------------
 
 sub install {
-	my $self     = shift;
-	my $weaver   = $self->weaver;
-	my $type     = $self->type;
-	my $pointcut = $self->pointcut;
-	my $code     = $self->code;
-
-	# Find all pointcuts that are statically matched
-	# wrap the method with advice code and install the wrapper
-	foreach my $sub_name ($weaver->get_sub_names) {
-		next unless $pointcut->match_define($sub_name);
-		my $wrapped_code = $self->wrap_code($type, $code, $pointcut, $sub_name);
-		$self->add_hooks(
-			$weaver->install($type, $sub_name, $wrapped_code)
-		);
-	}
-}
-
-# return wrapper sub to be installed instead of original
-# wrapper sub creates context then calls advice code
-# it runs only if the pointcut answers true to match_run()
-sub wrap_code {
-	my ($self, $type, $code, $pointcut, $sub_name) = @_;
-
-	return sub {
-		# Hacked Hook::LexWrap calls hooks with 3 params
-		my ($params, $original, $return_value) = @_;
-		my $runtime_context = {};
-		return unless $pointcut->match_run($sub_name, $runtime_context);
-
-		# Create context for advice code
-		my $advice_context = Aspect::AdviceContext->new(
-			sub_name       => $sub_name,
-			type           => $type,
-			pointcut       => $pointcut,
-			params         => $params,
-			return_value   => $return_value,
-			original       => $original,
-			%$runtime_context,
-		);
-		
-		# Execute advice code with its context
-		if (wantarray)
-			{ () = &$code($advice_context) }
-		elsif (defined wantarray)
-			{ my $dummy = &$code($advice_context) }
-		else
-			{ &$code($advice_context) }
-
-		# If proceeding to original, modify params, else modify return value
-		if ($type eq 'before' && $advice_context->proceed)
-			{ @$params = $advice_context->params }
-		else
-			{ $_[-1] = $advice_context->return_value }
-	};
+	die("Method 'install' is not implemented by " . ref($_[0]));
 }
 
 sub add_hooks {
 	push @{shift->{hooks}}, shift;
 }
 
-sub weaver {
-	$_[0]->{weaver};
-}
-
 sub type {
-	$_[0]->{type};
+	die("Method 'type' is not implemented by " . ref($_[0]));
 }
 
 sub code {
