@@ -4,10 +4,10 @@ use strict;
 use warnings;
 use Carp;
 use Aspect;
+use Aspect::Modular ();
 
-our $VERSION = '0.22';
-
-use base 'Aspect::Modular';
+our $VERSION = '0.23';
+our @ISA     = 'Aspect::Modular';
 
 my %Cache;
 
