@@ -3,19 +3,15 @@ package Aspect::Pointcut::AndOp;
 use strict;
 use warnings;
 use Carp;
+use Aspect::Pointcut::BinOp ();
 
-
-our $VERSION = '0.22';
-
-
-use base 'Aspect::Pointcut::BinOp';
+our $VERSION = '0.23';
+our @ISA     = 'Aspect::Pointcut::BinOp';
 
 sub binop { $_[1] && $_[2] }
 
-
 1;
 
-
 __END__
 
 =pod
