@@ -3,12 +3,10 @@ package Aspect::Pointcut::BinOp;
 use strict;
 use warnings;
 use Carp;
+use Aspect::Pointcut ();
 
-
-our $VERSION = '0.22';
-
-
-use base 'Aspect::Pointcut';
+our $VERSION = '0.23';
+our @ISA     = 'Aspect::Pointcut';
 
 sub init {
 	my $self = shift;
