@@ -3,24 +3,22 @@ package Aspect::Pointcut::Call;
 use strict;
 use warnings;
 use Carp;
+use Aspect::Pointcut ();
 
+our $VERSION = '0.23';
+our @ISA     = 'Aspect::Pointcut';
 
-our $VERSION = '0.22';
-
-
-use base 'Aspect::Pointcut';
-
-sub init { shift->{spec} = pop }
+sub init {
+	shift->{spec} = pop;
+}
 
 sub match_define {
 	my ($self, $sub_name) = @_;
 	return $self->match($self->{spec}, $sub_name);
 }
 
-
 1;
 
-
 __END__
 
 =pod
