@@ -8,7 +8,7 @@ use Aspect::Pointcut::Call;
 
 use base qw(Test::Class);
 
-my ($good_method, $bad_method) =	qw(
+my ($good_method, $bad_method) = qw(
 	SomePackage::some_method
 	SomePackage::no_method
 );
@@ -24,10 +24,10 @@ sub match_define: Test(6) {
 
 sub pointcut_ok {
 	my ($self, %assertions) = @_;
-	for my $type (keys %assertions) {
+	for my $type ( keys %assertions ) {
 		my $subject = Aspect::Pointcut::Call->new($assertions{$type});
-		ok $subject->match_define($good_method), "$type match";
-		ok !$subject->match_define($bad_method), "$type no match";
+		ok(   $subject->match_define($good_method), "$type match"    );
+		ok( ! $subject->match_define($bad_method),  "$type no match" );
 	}
 }
 
