@@ -3,13 +3,15 @@
 package Test::Exception;
 use 5.005;
 use strict;
+use Exporter ();
 use Test::Builder;
 use Sub::Uplevel;
-use base qw(Exporter);
+
+our @ISA = 'Exporter';
 
 use vars qw($VERSION @EXPORT @EXPORT_OK);
 
-$VERSION = '0.21';
+$VERSION = '0.23';
 @EXPORT = qw(dies_ok lives_ok throws_ok lives_and);
 
 my $Tester = Test::Builder->new;
